searchData={"items":[{"type":"module","title":"Intel471Ex","doc":"Client library for Intel 471's Titan API.\n\nThis library provides functions to interact with the Titan API for gathering cyber threat intelligence.\nConfiguration is handled via system environment variables.","ref":"Intel471Ex.html"},{"type":"function","title":"Intel471Ex.config/0","doc":"Retrieves the configuration from environment variables.","ref":"Intel471Ex.html#config/0"},{"type":"function","title":"Environment Variables - Intel471Ex.config/0","doc":"- `INTEL471_USERNAME`: Your email address used for authentication\n- `INTEL471_API_KEY`: Your API key\n- `INTEL471_API_VERSION`: Optional API version\n- `INTEL471_API_URL`: Optional custom API URL","ref":"Intel471Ex.html#config/0-environment-variables"},{"type":"function","title":"Returns - Intel471Ex.config/0","doc":"A map containing the configuration values.","ref":"Intel471Ex.html#config/0-returns"},{"type":"function","title":"Examples - Intel471Ex.config/0","doc":"iex> System.put_env(\"INTEL471_USERNAME\", \"user@example.com\")\n    iex> System.put_env(\"INTEL471_API_KEY\", \"secret\")\n    iex> config = Intel471Ex.config()\n    iex> config.username\n    \"user@example.com\"","ref":"Intel471Ex.html#config/0-examples"},{"type":"module","title":"Intel471Ex.Actors","doc":"Functions for working with the Intel 471 Titan Actors API.","ref":"Intel471Ex.Actors.html"},{"type":"function","title":"Intel471Ex.Actors.get/1","doc":"Get a single actor by UID.","ref":"Intel471Ex.Actors.html#get/1"},{"type":"function","title":"Parameters - Intel471Ex.Actors.get/1","doc":"- `uid`: The unique identifier of the actor","ref":"Intel471Ex.Actors.html#get/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Actors.get/1","doc":"iex> Intel471Ex.Actors.get(\"e7fafbb8f44a6ded005c154976627da4\")\n    {:ok, %{...}}","ref":"Intel471Ex.Actors.html#get/1-examples"},{"type":"function","title":"Intel471Ex.Actors.search/1","doc":"Search actors using filter criteria.","ref":"Intel471Ex.Actors.html#search/1"},{"type":"function","title":"Parameters - Intel471Ex.Actors.search/1","doc":"- `params`: A map of query parameters for filtering actors\n  - `:actor` - Search for handles only\n  - `:forum` - Search for actors active on given forum\n  - `:from` - Search data starting from given creation time\n  - `:until` - Search data ending before given creation time\n  - `:lastUpdatedFrom` - Search data starting from given last updated time\n  - `:lastUpdatedUntil` - Search data ending before given last updated time\n  - `:sort` - Sort results (relevance, earliest, latest)\n  - `:offset` - Skip leading number of records\n  - `:count` - Returns given number of records","ref":"Intel471Ex.Actors.html#search/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Actors.search/1","doc":"iex> Intel471Ex.Actors.search(%{actor: \"synthx\"})\n    {:ok, %{\"actorTotalCount\" => 35, \"actors\" => [...]}}","ref":"Intel471Ex.Actors.html#search/1-examples"},{"type":"module","title":"Intel471Ex.Alerts","doc":"Functions for working with the Intel 471 Titan Alerts API.","ref":"Intel471Ex.Alerts.html"},{"type":"function","title":"Intel471Ex.Alerts.list/1","doc":"Get alerts triggered by user-defined watchers.","ref":"Intel471Ex.Alerts.html#list/1"},{"type":"function","title":"Parameters - Intel471Ex.Alerts.list/1","doc":"- `params`: A map of query parameters for filtering alerts\n  - `:from` - Search data starting from given creation time\n  - `:until` - Search data ending before given creation time\n  - `:count` - Returns given number of records\n  - `:offset` - UID of the latest already acquired alert\n  - `:watcherGroup` - Show alerts from specified watcher group only\n  - `:showRead` - Show read alerts (default: true)\n  - `:displayWatchers` - Show watcher groups info (default: false)\n  - `:markAsRead` - Mark displayed alerts as read (default: false)\n  - `:sort` - Sort results (earliest, latest)","ref":"Intel471Ex.Alerts.html#list/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Alerts.list/1","doc":"iex> Intel471Ex.Alerts.list(%{count: 10})\n    {:ok, %{\"alertTotalCount\" => 613, \"alerts\" => [...]}}","ref":"Intel471Ex.Alerts.html#list/1-examples"},{"type":"module","title":"Intel471Ex.Client","doc":"HTTP Client for Intel 471 Titan API using Req.","ref":"Intel471Ex.Client.html"},{"type":"function","title":"Intel471Ex.Client.request/5","doc":"Makes an API request to Intel 471 Titan API.","ref":"Intel471Ex.Client.html#request/5"},{"type":"function","title":"Parameters - Intel471Ex.Client.request/5","doc":"- `method`: HTTP method (:get, :post, :put, :delete)\n- `path`: API endpoint path\n- `params`: Query parameters (optional)\n- `body`: Request body for POST/PUT requests (optional)\n- `config`: Optional configuration override","ref":"Intel471Ex.Client.html#request/5-parameters"},{"type":"function","title":"Returns - Intel471Ex.Client.request/5","doc":"- `{:ok, response}` - Successful response with parsed JSON\n- `{:error, reason}` - Error with reason","ref":"Intel471Ex.Client.html#request/5-returns"},{"type":"module","title":"Intel471Ex.Credentials","doc":"Functions for working with credential-related endpoints in the Intel 471 Titan API.","ref":"Intel471Ex.Credentials.html"},{"type":"function","title":"Intel471Ex.Credentials.search_credential_occurrences/1","doc":"Search credential occurrences using filter criteria.","ref":"Intel471Ex.Credentials.html#search_credential_occurrences/1"},{"type":"function","title":"Parameters - Intel471Ex.Credentials.search_credential_occurrences/1","doc":"- `params`: A map of query parameters for filtering credential occurrences\n  - `:text` - Search text everywhere in credential occurrences\n  - `:credentialOccurrenceUid` - Search by credential occurrence uid\n  - `:credentialUid` - Search by credential uid\n  - `:accessedUrl` - Search by accessed url","ref":"Intel471Ex.Credentials.html#search_credential_occurrences/1-parameters"},{"type":"function","title":"Intel471Ex.Credentials.search_credential_sets/1","doc":"Search credential sets using filter criteria.","ref":"Intel471Ex.Credentials.html#search_credential_sets/1"},{"type":"function","title":"Parameters - Intel471Ex.Credentials.search_credential_sets/1","doc":"- `params`: A map of query parameters for filtering credential sets\n  - `:text` - Search text everywhere in credential sets\n  - `:credentialSetName` - Search by credential set name\n  - `:credentialSetUid` - Search by credential set uid\n  - `:victim` - Search by purported victim\n  - `:gir` - Search by General Intel Requirements","ref":"Intel471Ex.Credentials.html#search_credential_sets/1-parameters"},{"type":"function","title":"Intel471Ex.Credentials.search_credentials/1","doc":"Search credentials using filter criteria.","ref":"Intel471Ex.Credentials.html#search_credentials/1"},{"type":"function","title":"Parameters - Intel471Ex.Credentials.search_credentials/1","doc":"- `params`: A map of query parameters for filtering credentials\n  - `:text` - Search text everywhere in credentials\n  - `:credentialUid` - Search by credential uid\n  - `:credentialSetName` - Search by credential set name\n  - `:credentialDomain` - Search by credential domain\n  - `:passwordStrength` - Search by password strength\n  - `:credentialLogin` - Search by credential login","ref":"Intel471Ex.Credentials.html#search_credentials/1-parameters"},{"type":"function","title":"Intel471Ex.Credentials.stream_credential_occurrences/1","doc":"Stream credential occurrences using filter criteria.","ref":"Intel471Ex.Credentials.html#stream_credential_occurrences/1"},{"type":"function","title":"Parameters - Intel471Ex.Credentials.stream_credential_occurrences/1","doc":"- `params`: A map of query parameters for filtering credential occurrences\n  - `:text` - Search text everywhere in credential occurrences\n  - `:credentialOccurrenceUid` - Search by credential occurrence uid\n  - `:credentialUid` - Search by credential uid\n  - `:accessedUrl` - Search by accessed url\n  - `:cursor` - Continue scrolling from cursor","ref":"Intel471Ex.Credentials.html#stream_credential_occurrences/1-parameters"},{"type":"function","title":"Intel471Ex.Credentials.stream_credential_sets/1","doc":"Stream credential sets using filter criteria.","ref":"Intel471Ex.Credentials.html#stream_credential_sets/1"},{"type":"function","title":"Parameters - Intel471Ex.Credentials.stream_credential_sets/1","doc":"- `params`: A map of query parameters for filtering credential sets\n  - `:text` - Search text everywhere in credential sets\n  - `:credentialSetName` - Search by credential set name\n  - `:cursor` - Continue scrolling from cursor\n  - `:victim` - Search by purported victim\n  - `:gir` - Search by General Intel Requirements","ref":"Intel471Ex.Credentials.html#stream_credential_sets/1-parameters"},{"type":"module","title":"Intel471Ex.Downloader","doc":"File downloader for Intel 471 Titan API using Req.","ref":"Intel471Ex.Downloader.html"},{"type":"function","title":"Intel471Ex.Downloader.download_file/4","doc":"Downloads a file from Intel 471 Titan API.","ref":"Intel471Ex.Downloader.html#download_file/4"},{"type":"function","title":"Parameters - Intel471Ex.Downloader.download_file/4","doc":"- `url`: Full URL to the file (e.g., \"https://api.intel471.com/v1/dataleak/download/archives/interlock/25154/structure.zip\")\n- `destination`: Local path where the file should be saved\n- `params`: Query parameters (optional)\n- `config`: Optional configuration override","ref":"Intel471Ex.Downloader.html#download_file/4-parameters"},{"type":"function","title":"Returns - Intel471Ex.Downloader.download_file/4","doc":"- `{:ok, path}` - Successful download with path to saved file\n- `{:error, reason}` - Error with reason","ref":"Intel471Ex.Downloader.html#download_file/4-returns"},{"type":"function","title":"Intel471Ex.Downloader.download_file_auto/4","doc":"Downloads a file from Intel 471 Titan API and automatically extracts the filename from the URL.","ref":"Intel471Ex.Downloader.html#download_file_auto/4"},{"type":"function","title":"Parameters - Intel471Ex.Downloader.download_file_auto/4","doc":"- `url`: Full URL to the file\n- `destination_dir`: Directory where the file should be saved (default: \"downloads\")\n- `params`: Query parameters (optional)\n- `config`: Optional configuration override","ref":"Intel471Ex.Downloader.html#download_file_auto/4-parameters"},{"type":"function","title":"Returns - Intel471Ex.Downloader.download_file_auto/4","doc":"- `{:ok, path}` - Successful download with path to saved file\n- `{:error, reason}` - Error with reason","ref":"Intel471Ex.Downloader.html#download_file_auto/4-returns"},{"type":"module","title":"Intel471Ex.Reports","doc":"Functions for working with various report types from the Intel 471 Titan API.","ref":"Intel471Ex.Reports.html"},{"type":"function","title":"Intel471Ex.Reports.breach_alerts/1","doc":"Search breach alerts using filter criteria.","ref":"Intel471Ex.Reports.html#breach_alerts/1"},{"type":"function","title":"Parameters - Intel471Ex.Reports.breach_alerts/1","doc":"- `params`: A map of query parameters for filtering breach alerts\n  - `:breachAlert` - Free text reports search\n  - `:actor` - Search by actor or actor group names\n  - `:victim` - Search by victim\n  - `:confidence` - Search by confidence level","ref":"Intel471Ex.Reports.html#breach_alerts/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Reports.breach_alerts/1","doc":"iex> Intel471Ex.Reports.breach_alerts(%{breachAlert: \"Communications\"})\n    {:ok, %{\"breach_alerts_total_count\" => 2337, \"breach_alerts\" => [...]}}","ref":"Intel471Ex.Reports.html#breach_alerts/1-examples"},{"type":"function","title":"Intel471Ex.Reports.get/1","doc":"Get a single report by UID.","ref":"Intel471Ex.Reports.html#get/1"},{"type":"function","title":"Parameters - Intel471Ex.Reports.get/1","doc":"- `uid`: The unique identifier of the report","ref":"Intel471Ex.Reports.html#get/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Reports.get/1","doc":"iex> Intel471Ex.Reports.get(\"32537c9c6dce18ce6ea4d5106540f089\")\n    {:ok, %{...}}","ref":"Intel471Ex.Reports.html#get/1-examples"},{"type":"function","title":"Intel471Ex.Reports.get_breach_alert/1","doc":"Get a breach alert by UID.","ref":"Intel471Ex.Reports.html#get_breach_alert/1"},{"type":"function","title":"Parameters - Intel471Ex.Reports.get_breach_alert/1","doc":"- `uid`: The unique identifier of the breach alert","ref":"Intel471Ex.Reports.html#get_breach_alert/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Reports.get_breach_alert/1","doc":"iex> Intel471Ex.Reports.get_breach_alert(\"8c5e0e87e683c62bb0a50baeff732152\")\n    {:ok, %{...}}","ref":"Intel471Ex.Reports.html#get_breach_alert/1-examples"},{"type":"function","title":"Intel471Ex.Reports.malware_reports/1","doc":"Search malware intelligence reports.","ref":"Intel471Ex.Reports.html#malware_reports/1"},{"type":"function","title":"Parameters - Intel471Ex.Reports.malware_reports/1","doc":"- `params`: A map of query parameters for filtering malware reports\n  - `:malwareReport` - Free text malware reports search\n  - `:threatType` - Search by threat type\n  - `:malwareFamily` - Search by malware family","ref":"Intel471Ex.Reports.html#malware_reports/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Reports.malware_reports/1","doc":"iex> Intel471Ex.Reports.malware_reports(%{malwareFamily: \"lokibot\"})\n    {:ok, %{\"malwareReportTotalCount\" => 52, \"malwareReports\" => [...]}}","ref":"Intel471Ex.Reports.html#malware_reports/1-examples"},{"type":"function","title":"Intel471Ex.Reports.search/1","doc":"Search information reports using filter criteria.","ref":"Intel471Ex.Reports.html#search/1"},{"type":"function","title":"Parameters - Intel471Ex.Reports.search/1","doc":"- `params`: A map of query parameters for filtering reports\n  - `:report` - Search text in reports, subjects, and entities\n  - `:reportLocation` - Search reports by country or region\n  - `:reportTag` - Search reports by tag\n  - `:reportTitle` - Search reports by title\n  - `:victim` - Search reports by purported victim\n  - `:documentType` - Search reports by document type\n  - `:gir` - Search by General Intel Requirements\n  - `:from` - Search data starting from given creation time\n  - `:until` - Search data ending before given creation time","ref":"Intel471Ex.Reports.html#search/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Reports.search/1","doc":"iex> Intel471Ex.Reports.search(%{report: \"ransomware\"})\n    {:ok, %{\"reportTotalCount\" => 28, \"reports\" => [...]}}","ref":"Intel471Ex.Reports.html#search/1-examples"},{"type":"function","title":"Intel471Ex.Reports.situation_reports/1","doc":"Search situation reports using filter criteria.","ref":"Intel471Ex.Reports.html#situation_reports/1"},{"type":"function","title":"Parameters - Intel471Ex.Reports.situation_reports/1","doc":"- `params`: A map of query parameters for filtering situation reports\n  - `:situationReport` - Free text reports search\n  - `:victim` - Search by purported victim\n  - `:gir` - Search by General Intel Requirements","ref":"Intel471Ex.Reports.html#situation_reports/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Reports.situation_reports/1","doc":"iex> Intel471Ex.Reports.situation_reports(%{situationReport: \"malware\"})\n    {:ok, %{\"situationReportsTotalCount\" => 11, \"situationReports\" => [...]}}","ref":"Intel471Ex.Reports.html#situation_reports/1-examples"},{"type":"function","title":"Intel471Ex.Reports.spot_reports/1","doc":"Search spot reports using filter criteria.","ref":"Intel471Ex.Reports.html#spot_reports/1"},{"type":"function","title":"Parameters - Intel471Ex.Reports.spot_reports/1","doc":"- `params`: A map of query parameters for filtering spot reports\n  - `:spotReport` - Free text reports search\n  - `:victim` - Search by purported victim\n  - `:gir` - Search by General Intel Requirements","ref":"Intel471Ex.Reports.html#spot_reports/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Reports.spot_reports/1","doc":"iex> Intel471Ex.Reports.spot_reports(%{spotReport: \"malware\"})\n    {:ok, %{\"spotReportsTotalCount\" => 123, \"spotReports\" => [...]}}","ref":"Intel471Ex.Reports.html#spot_reports/1-examples"},{"type":"module","title":"Intel471Ex.Search","doc":"Functions for performing global search across multiple data types in the Intel 471 Titan API.","ref":"Intel471Ex.Search.html"},{"type":"function","title":"Intel471Ex.Search.search/1","doc":"Perform a global search across multiple data types.","ref":"Intel471Ex.Search.html#search/1"},{"type":"function","title":"Parameters - Intel471Ex.Search.search/1","doc":"- `params`: A map of query parameters for the search\n  - `:text` - Search text everywhere\n  - `:ipAddress` - IP address search\n  - `:url` - URL search\n  - `:contactInfoEmail` - E-mail address search\n  - `:post` - Forum post search\n  - `:privateMessage` - Forum private message search\n  - `:actor` - Actor search\n  - `:entity` - Entity search\n  - `:entityType` - Search by entity type\n  - `:victim` - Purported victim search\n  - Many other parameters - see the API docs","ref":"Intel471Ex.Search.html#search/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Search.search/1","doc":"iex> Intel471Ex.Search.search(%{text: \"ransomware\"})\n    {:ok, %{\n      \"actorTotalCount\" => 41,\n      \"reportTotalCount\" => 35,\n      \"actors\" => [...],\n      \"reports\" => [...]\n    }}","ref":"Intel471Ex.Search.html#search/1-examples"},{"type":"module","title":"Intel471Ex.Vulnerabilities","doc":"Functions for working with the Vulnerabilities API endpoints.","ref":"Intel471Ex.Vulnerabilities.html"},{"type":"function","title":"Intel471Ex.Vulnerabilities.cve_reports/1","doc":"Search vulnerability reports (CVEs) using filter criteria.","ref":"Intel471Ex.Vulnerabilities.html#cve_reports/1"},{"type":"function","title":"Parameters - Intel471Ex.Vulnerabilities.cve_reports/1","doc":"- `params`: A map of query parameters for filtering CVE reports\n  - `:cveReport` - Free text CVE reports search\n  - `:cveType` - Search CVE reports by type\n  - `:cveStatus` - Search CVE reports by status\n  - `:cveName` - Search CVE reports by name\n  - `:riskLevel` - Search CVE reports by risk level (high, medium, low)\n  - `:patchStatus` - Search CVE reports by patch status\n  - `:vendorName` - Search CVE reports by vendor name\n  - `:productName` - Search CVE reports by product name","ref":"Intel471Ex.Vulnerabilities.html#cve_reports/1-parameters"},{"type":"function","title":"Intel471Ex.Vulnerabilities.get_cve_report/1","doc":"Get a CVE report by UID.","ref":"Intel471Ex.Vulnerabilities.html#get_cve_report/1"},{"type":"function","title":"Parameters - Intel471Ex.Vulnerabilities.get_cve_report/1","doc":"- `config`: A Intel471Ex.Config struct with authentication details\n- `uid`: The unique identifier of the CVE report","ref":"Intel471Ex.Vulnerabilities.html#get_cve_report/1-parameters"},{"type":"module","title":"Intel471Ex.Watchers","doc":"Functions for working with Watcher Groups API endpoints in the Intel 471 Titan API.","ref":"Intel471Ex.Watchers.html"},{"type":"function","title":"Intel471Ex.Watchers.create_group/1","doc":"Create a new watcher group.","ref":"Intel471Ex.Watchers.html#create_group/1"},{"type":"function","title":"Parameters - Intel471Ex.Watchers.create_group/1","doc":"- `body`: A map containing the watcher group details\n  - `:name` - Name of the Watcher Group\n  - `:description` - Description of the Watcher Group","ref":"Intel471Ex.Watchers.html#create_group/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Watchers.create_group/1","doc":"iex> body = %{name: \"Early Warning Watchers\", description: \"This watcher group consists mainly of...\"}\n    iex> Intel471Ex.Watchers.create_group(body)\n    {:ok, %{\"name\" => \"Early Warning Watchers\", \"uid\" => \"0bd66b73-c445-4b35-b3d4-742ed1e5a092\", ...}}","ref":"Intel471Ex.Watchers.html#create_group/1-examples"},{"type":"function","title":"Intel471Ex.Watchers.create_watcher/2","doc":"Create a new watcher in a watcher group.","ref":"Intel471Ex.Watchers.html#create_watcher/2"},{"type":"function","title":"Parameters - Intel471Ex.Watchers.create_watcher/2","doc":"- `group_uid`: The unique identifier of the watcher group\n- `body`: A map containing the watcher details\n  - `:description` - Watcher description\n  - `:type` - Watcher type (search or thread)\n  - `:patterns` - Search patterns for search watcher\n  - `:notificationChannel` - Notification channel\n  - `:notificationFrequency` - Notification frequency","ref":"Intel471Ex.Watchers.html#create_watcher/2-parameters"},{"type":"function","title":"Examples - Intel471Ex.Watchers.create_watcher/2","doc":"iex> body = %{\n    ...>   type: \"search\", \n    ...>   description: \"Searching for ransomware\", \n    ...>   patterns: [%{types: \"FreeText\", pattern: \"ransomware\"}],\n    ...>   notificationChannel: \"website\",\n    ...>   notificationFrequency: \"immediately\"\n    ...> }\n    iex> Intel471Ex.Watchers.create_watcher(\"0bd66b73-c445-4b35-b3d4-742ed1e5a092\", body)\n    {:ok, %{\"uid\" => \"e1ada07bf9d0a14884844bcd85cd785a\", ...}}","ref":"Intel471Ex.Watchers.html#create_watcher/2-examples"},{"type":"function","title":"Intel471Ex.Watchers.delete_watcher/2","doc":"Delete a watcher.","ref":"Intel471Ex.Watchers.html#delete_watcher/2"},{"type":"function","title":"Parameters - Intel471Ex.Watchers.delete_watcher/2","doc":"- `group_uid`: The unique identifier of the watcher group\n- `watcher_uid`: The unique identifier of the watcher","ref":"Intel471Ex.Watchers.html#delete_watcher/2-parameters"},{"type":"function","title":"Examples - Intel471Ex.Watchers.delete_watcher/2","doc":"iex> Intel471Ex.Watchers.delete_watcher(\"0bd66b73-c445-4b35-b3d4-742ed1e5a092\", \"e1ada07bf9d0a14884844bcd85cd785a\")\n    {:ok, nil}","ref":"Intel471Ex.Watchers.html#delete_watcher/2-examples"},{"type":"function","title":"Intel471Ex.Watchers.list_groups/1","doc":"Get a list of watcher groups.","ref":"Intel471Ex.Watchers.html#list_groups/1"},{"type":"function","title":"Parameters - Intel471Ex.Watchers.list_groups/1","doc":"- `params`: A map of query parameters for filtering watcher groups\n  - `:section` - Shows watcher groups from defined section (myGroups, sharedWithMe, sharedByIntel471)","ref":"Intel471Ex.Watchers.html#list_groups/1-parameters"},{"type":"function","title":"Examples - Intel471Ex.Watchers.list_groups/1","doc":"iex> Intel471Ex.Watchers.list_groups()\n    {:ok, %{\"watcherGroupTotalCount\" => 3, \"watcherGroups\" => [...]}}","ref":"Intel471Ex.Watchers.html#list_groups/1-examples"},{"type":"extras","title":"Intel471Ex","doc":"# Intel471Ex\n\nAn Elixir client library for Intel 471's Titan API providing access to cyber threat intelligence.","ref":"readme.html"},{"type":"extras","title":"Table of Contents - Intel471Ex","doc":"- [Installation](#installation)\n- [Configuration](#configuration)\n- [Basic Usage](#basic-usage)\n- [API Examples](#api-examples)\n  - [Actors](#actors)\n  - [Alerts](#alerts)\n  - [Reports](#reports)\n  - [Credentials](#credentials)\n  - [Vulnerabilities](#vulnerabilities)\n  - [IOCs](#iocs)\n  - [Search](#search)\n  - [Watchers](#watchers)\n  - [Malware Intelligence](#malware-intelligence)\n- [Working with Streams](#working-with-streams)\n- [Error Handling](#error-handling)","ref":"readme.html#table-of-contents"},{"type":"extras","title":"Installation - Intel471Ex","doc":"Add `intel471_titan` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:intel471_titan, \"~> 0.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Configuration - Intel471Ex","doc":"This library uses system environment variables for authentication and configuration:\n\n```\n# Required\nINTEL471_USERNAME=your-email@example.com\nINTEL471_API_KEY=your-api-key\n\n# Optional\nINTEL471_API_URL=https://api.intel471.com/v1  # Default API URL\nINTEL471_API_VERSION=1.20.0                   # Optional API version\n```\n\nYou can set these environment variables in your system or within your application:\n\n```elixir\n# Set in your application\nSystem.put_env(\"INTEL471_USERNAME\", \"your-email@example.com\")\nSystem.put_env(\"INTEL471_API_KEY\", \"your-api-key\")\n```","ref":"readme.html#configuration"},{"type":"extras","title":"Basic Usage - Intel471Ex","doc":"```elixir\n# Fetch actors matching \"threat_actor\"\n{:ok, result} = Intel471Ex.Actors.search(%{actor: \"threat_actor\"})\nIO.puts(\"Found #{result[\"actorTotalCount\"]} actors\")\n\n# Get a specific report\n{:ok, report} = Intel471Ex.Reports.get(\"32537c9c6dce18ce6ea4d5106540f089\")\nIO.puts(\"Report title: #{report[\"subject\"]}\")\n```","ref":"readme.html#basic-usage"},{"type":"extras","title":"API Examples - Intel471Ex","doc":"","ref":"readme.html#api-examples"},{"type":"extras","title":"Actors - Intel471Ex","doc":"```elixir\n# Search for actors\n{:ok, result} = Intel471Ex.Actors.search(%{actor: \"synthx\"})\nIO.inspect(result[\"actorTotalCount\"])\n\n# Search actors active on a specific forum\n{:ok, result} = Intel471Ex.Actors.search(%{forum: \"0day\"})\n\n# Get a specific actor by UID\n{:ok, actor} = Intel471Ex.Actors.get(\"e7fafbb8f44a6ded005c154976627da4\")\nIO.inspect(actor[\"handles\"])\n```","ref":"readme.html#actors"},{"type":"extras","title":"Alerts - Intel471Ex","doc":"```elixir\n# Get recent alerts (last 24 hours)\n{:ok, result} = Intel471Ex.Alerts.list(%{from: \"24hours\", count: 10})\nIO.puts(\"Found #{result[\"alertTotalCount\"]} alerts\")\n\n# Get alerts from a specific watcher group\n{:ok, result} = Intel471Ex.Alerts.list(%{watcherGroup: \"10dce938-3db9-463b-9c2f-b485ab398805\"})\n\n# Continue pagination using the last alert's UID\nlast_alert_uid = List.last(result[\"alerts\"])[\"uid\"]\n{:ok, next_page} = Intel471Ex.Alerts.list(%{count: 10, offset: last_alert_uid})\n```","ref":"readme.html#alerts"},{"type":"extras","title":"Reports - Intel471Ex","doc":"```elixir\n# Search for reports about ransomware\n{:ok, result} = Intel471Ex.Reports.search(%{report: \"ransomware\"})\nIO.puts(\"Found #{result[\"reportTotalCount\"]} reports\")\n\n# Search reports by location\n{:ok, result} = Intel471Ex.Reports.search(%{reportLocation: \"Germany\"})\n\n# Get a specific report\n{:ok, report} = Intel471Ex.Reports.get(\"32537c9c6dce18ce6ea4d5106540f089\")\n\n# Search breach alerts\n{:ok, alerts} = Intel471Ex.Reports.breach_alerts(%{breachAlert: \"Communications\"})\n\n# Get a specific breach alert\n{:ok, alert} = Intel471Ex.Reports.get_breach_alert(\"8c5e0e87e683c62bb0a50baeff732152\")\n\n# Search spot reports\n{:ok, reports} = Intel471Ex.Reports.spot_reports(%{spotReport: \"malware\"})\n\n# Search situation reports\n{:ok, reports} = Intel471Ex.Reports.situation_reports(%{situationReport: \"ransomware\"})\n\n# Search malware intelligence reports\n{:ok, reports} = Intel471Ex.Reports.malware_reports(%{malwareFamily: \"lokibot\"})\n```","ref":"readme.html#reports"},{"type":"extras","title":"Credentials - Intel471Ex","doc":"```elixir\n# Search credential sets\n{:ok, result} = Intel471Ex.Credentials.search_credential_sets(%{text: \"breach\"})\n\n# Stream credential sets\n{:ok, result} = Intel471Ex.Credentials.stream_credential_sets(%{lastUpdatedFrom: 1656809200000})\n\n# With cursor for pagination\ncursor = result.cursor_next\n{:ok, next_page} = Intel471Ex.Credentials.stream_credential_sets(%{\n  lastUpdatedFrom: 1656809200000,\n  cursor: cursor\n})\n\n# Search credentials\n{:ok, creds} = Intel471Ex.Credentials.search_credentials(%{\n  credentialDomain: \"example.com\",\n  passwordStrength: \"weak\"\n})\n\n# Search credential occurrences\n{:ok, occurrences} = Intel471Ex.Credentials.search_credential_occurrences(%{\n  accessedUrl: \"login.example.com\"\n})\n\n# Search accessed URLs\n{:ok, urls} = Intel471Ex.Credentials.search_credential_accessed_urls(%{\n  domain: \"example.com\"\n})\n```","ref":"readme.html#credentials"},{"type":"extras","title":"Vulnerabilities - Intel471Ex","doc":"```elixir\n# Search for CVEs\n{:ok, vulns} = Intel471Ex.Vulnerabilities.cve_reports(%{\n  productName: \"Chrome\",\n  riskLevel: \"high\"\n})\n\n# Get a specific CVE\n{:ok, cve} = Intel471Ex.Vulnerabilities.get_cve_report(\"d6ec93bf8fdf355f7b35a3bc2c15566b\")\n\n# Filter by patch status\n{:ok, unpatchedCVEs} = Intel471Ex.Vulnerabilities.cve_reports(%{\n  patchStatus: \"unavailable\",\n  riskLevel: \"high\"\n})\n```","ref":"readme.html#vulnerabilities"},{"type":"extras","title":"IOCs - Intel471Ex","doc":"```elixir\n# Search for Indicators of Compromise\n{:ok, result} = Intel471Ex.IOCs.search(%{ioc: \".com\"})\n\n# Search by IOC type\n{:ok, result} = Intel471Ex.IOCs.search(%{\n  ioc: \"192.168\",\n  iocType: \"IPAddress\"\n})\n```","ref":"readme.html#iocs"},{"type":"extras","title":"Search - Intel471Ex","doc":"```elixir\n# Perform a global search across all data types\n{:ok, result} = Intel471Ex.Search.search(%{text: \"ransomware\"})\n\n# Search for specific entity types\n{:ok, result} = Intel471Ex.Search.search(%{\n  entityType: \"EmailAddress\",\n  text: \"admin@\"\n})\n\n# Search by IP address\n{:ok, result} = Intel471Ex.Search.search(%{ipAddress: \"192.168.1.1\"})\n\n# Search by URL\n{:ok, result} = Intel471Ex.Search.search(%{url: \"malicious-site.com\"})\n\n# Combined search\n{:ok, result} = Intel471Ex.Search.search(%{\n  text: \"ransomware\",\n  reportLocation: \"United States\",\n  from: 1627776000000,\n  until: 1627948800000\n})\n```","ref":"readme.html#search"},{"type":"extras","title":"Watchers - Intel471Ex","doc":"```elixir\n# List watcher groups\n{:ok, groups} = Intel471Ex.Watchers.list_groups()\n\n# Create a new watcher group\n{:ok, group} = Intel471Ex.Watchers.create_group(%{\n  name: \"Ransomware Monitoring\",\n  description: \"Monitor for new ransomware threats\"\n})\n\n# Get a specific watcher group\n{:ok, group} = Intel471Ex.Watchers.list_groups(\"0bd66b73-c445-4b35-b3d4-742ed1e5a092\")\n\n# Create a free text search watcher\n{:ok, watcher} = Intel471Ex.Watchers.create_watcher(\n  \"0bd66b73-c445-4b35-b3d4-742ed1e5a092\",\n  %{\n    type: \"search\",\n    description: \"Monitor for ransomware mentions\",\n    patterns: [%{types: \"FreeText\", pattern: \"ransomware\"}],\n    notificationChannel: \"website\",\n    notificationFrequency: \"immediately\"\n  }\n)\n\n# Create a specific search watcher\n{:ok, watcher} = Intel471Ex.Watchers.create_watcher(\n  \"0bd66b73-c445-4b35-b3d4-742ed1e5a092\",\n  %{\n    type: \"search\",\n    description: \"Monitor for actor mentions\",\n    patterns: [%{types: \"Actor\", pattern: \"swisman\"}],\n    notificationChannel: \"website\",\n    notificationFrequency: \"immediately\"\n  }\n)\n\n# Delete a watcher\n{:ok, _} = Intel471Ex.Watchers.delete_watcher(\n  \"0bd66b73-c445-4b35-b3d4-742ed1e5a092\",\n  \"e1ada07bf9d0a14884844bcd85cd785a\"\n)\n```","ref":"readme.html#watchers"},{"type":"extras","title":"Malware Intelligence - Intel471Ex","doc":"```elixir\n# Search for events\n{:ok, events} = Intel471Ex.Events.search(%{\n  malwareFamily: \"lokibot\"\n})\n\n# Stream events\n{:ok, stream} = Intel471Ex.Events.stream(%{\n  lastUpdatedFrom: 1655809200000\n})\n\n# Get next page using cursor\ncursor = stream.cursorNext\n{:ok, next_page} = Intel471Ex.Events.stream(%{\n  lastUpdatedFrom: 1655809200000,\n  cursor: cursor\n})\n\n# Search for indicators\n{:ok, indicators} = Intel471Ex.Indicators.search(%{\n  indicatorType: \"url\",\n  confidence: \"high\"\n})\n\n# Stream indicators\n{:ok, stream} = Intel471Ex.Indicators.stream(%{\n  lastUpdatedFrom: 1655809200000\n})\n\n# Search for YARA rules\n{:ok, yara} = Intel471Ex.YARA.search(%{\n  malwareFamily: \"trickbot\"\n})\n```","ref":"readme.html#malware-intelligence"},{"type":"extras","title":"Working with Streams - Intel471Ex","doc":"Many endpoints offer stream variants that use cursors for efficient pagination of large datasets:\n\n```elixir\n# Stream credential sets\n{:ok, result} = Intel471Ex.Credentials.stream_credential_sets(%{\n  lastUpdatedFrom: 1656809200000\n})\n\n# Process all pages\nprocess_all_pages = fn fetch_fn, params ->\n  # Initial request\n  {:ok, response} = fetch_fn.(params)\n  \n  # Process first page\n  process_items(response.credential_sets)\n  \n  # Continue with pagination using cursor\n  fetch_next_page = fn\n    nil, _acc -> :done\n    cursor, acc ->\n      case fetch_fn.(Map.put(params, :cursor, cursor)) do\n        {:ok, %{credential_sets: [], cursor_next: _}} -> \n          acc\n        {:ok, %{credential_sets: items, cursor_next: next_cursor}} ->\n          process_items(items)\n          fetch_next_page.(next_cursor, acc ++ items)\n        _ -> \n          acc\n      end\n  end\n  \n  fetch_next_page.(response.cursor_next, response.credential_sets)\nend\n\n# Usage example\nall_items = process_all_pages.(&Intel471Ex.Credentials.stream_credential_sets/1, %{\n  lastUpdatedFrom: 1656809200000\n})\n```","ref":"readme.html#working-with-streams"},{"type":"extras","title":"Error Handling - Intel471Ex","doc":"The API returns standard Elixir result tuples:\n\n```elixir\ncase Intel471Ex.Actors.search(%{actor: \"threat_actor\"}) do\n  {:ok, result} ->\n    # Process successful result\n    IO.puts(\"Found #{result[\"actorTotalCount\"]} actors\")\n    \n  {:error, %{status: status, message: message}} ->\n    # Handle API error\n    IO.puts(\"Error #{status}: #{message}\")\n    \n  {:error, exception} ->\n    # Handle other errors (network issues, etc.)\n    IO.puts(\"Exception: #{inspect(exception)}\")\nend\n```","ref":"readme.html#error-handling"},{"type":"extras","title":"Advanced Examples - Intel471Ex","doc":"","ref":"readme.html#advanced-examples"},{"type":"extras","title":"Combining Multiple Search Parameters - Intel471Ex","doc":"```elixir\n# Search for high-risk vulnerabilities affecting Chrome with no patch available\n{:ok, vulns} = Intel471Ex.Vulnerabilities.cve_reports(%{\n  productName: \"Chrome\",\n  riskLevel: \"high\",\n  patchStatus: \"unavailable\"\n})\n\n# Search for credential leaks from a specific domain in the last 30 days\n{:ok, creds} = Intel471Ex.Credentials.search_credentials(%{\n  credentialDomain: \"example.com\",\n  from: \"30days\"\n})\n\n# Search for ransomware-related reports in a specific region\n{:ok, reports} = Intel471Ex.Reports.search(%{\n  report: \"ransomware\",\n  reportLocation: \"Germany\"\n})\n```","ref":"readme.html#combining-multiple-search-parameters"},{"type":"extras","title":"Working with Dates and Time Ranges - Intel471Ex","doc":"```elixir\n# Using explicit timestamps (milliseconds since epoch)\n{:ok, actors} = Intel471Ex.Actors.search(%{\n  from: 1627776000000,  # July 31, 2021\n  until: 1630454400000  # September 1, 2021\n})\n\n# Using relative time strings\n{:ok, reports} = Intel471Ex.Reports.search(%{\n  report: \"vulnerability\",\n  from: \"7days\"  # Last 7 days\n})\n\n# Using both approaches in different parameters\n{:ok, alerts} = Intel471Ex.Alerts.list(%{\n  from: \"24hours\",\n  lastUpdatedFrom: 1655809200000\n})\n```","ref":"readme.html#working-with-dates-and-time-ranges"},{"type":"extras","title":"Filtering by GIR (General Intel Requirements) - Intel471Ex","doc":"```elixir\n# Search for reports matching a specific GIR\n{:ok, reports} = Intel471Ex.Reports.search(%{\n  report: \"malware\",\n  gir: \"1.1.3\"\n})\n\n# Filter by company PIRs (Prioritized Intel Requirements)\n{:ok, reports} = Intel471Ex.Reports.search(%{\n  report: \"ransomware\",\n  filterByGirSet: \"company_pirs\"\n})\n```","ref":"readme.html#filtering-by-gir-general-intel-requirements"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}